==> aom-docs-3.0.0-2-aarch64.pkg.tar.xz: usr/share/doc/aom/group__cyclic__refresh.js <==
var group__cyclic__refresh =
[
    [ "CYCLIC_REFRESH", "structCYCLIC__REFRESH.html", [
      [ "percent_refresh", "structCYCLIC__REFRESH.html#ae315bcaf369b95ab1162f2d1271263de", null ],
      [ "max_qdelta_perc", "structCYCLIC__REFRESH.html#a441d4805353c603874ae7f356a649cd3", null ],
      [ "sb_index", "structCYCLIC__REFRESH.html#ad45cfe66fc5d1ab8aecee9bc1ef72f44", null ],
      [ "time_for_refresh", "structCYCLIC__REFRESH.html#a14a2e1c9b9ca6a36bb29ccd9a0e02002", null ],
      [ "target_num_seg_blocks", "structCYCLIC__REFRESH.html#ac79bf4f50ebef3b6e6fd91e25af9a2c6", null ],
      [ "actual_num_seg1_blocks", "structCYCLIC__REFRESH.html#aebf6363e9a037324981bd3739cdce960", null ],
      [ "actual_num_seg2_blocks", "structCYCLIC__REFRESH.html#a7b30c416581337161479c00e08fed8ea", null ],
      [ "rdmult", "structCYCLIC__REFRESH.html#a383b90c4a87340a91580aac8a537aee6", null ],
      [ "map", "structCYCLIC__REFRESH.html#a5034d2e9cba349dd451d41f6362dc6f9", null ],
      [ "last_coded_q_map", "structCYCLIC__REFRESH.html#ad7b64393744b5619addd0780cfaed625", null ],
      [ "thresh_rate_sb", "structCYCLIC__REFRESH.html#a11f1a950d76b9908606d234eab0d8b2b", null ],
      [ "thresh_dist_sb", "structCYCLIC__REFRESH.html#a74276b39125b068743f0b6dc2ba0f36a", null ],
      [ "motion_thresh", "structCYCLIC__REFRESH.html#a08162f2bd6028160d470024577dfcec6", null ],
      [ "rate_ratio_qdelta", "structCYCLIC__REFRESH.html#afe7bf45e2c31665d7d64254c23fdaf6c", null ],
      [ "rate_boost_fac", "structCYCLIC__REFRESH.html#ae0966dda4b2470d422129ed473e39d4c", null ]
    ] ],
    [ "av1_cyclic_refresh_estimate_bits_at_q", "group__cyclic__refresh.html#ga3703e9a518f8f17e7b6b601a456dbde8", null ],
    [ "av1_cyclic_refresh_rc_bits_per_mb", "group__cyclic__refresh.html#ga1e8e194fae8285692651fb856b49c185", null ],
    [ "av1_cyclic_refresh_update_segment", "group__cyclic__refresh.html#gad2535f695b7eb56962a1cd52c153688f", null ],
    [ "av1_cyclic_refresh_postencode", "group__cyclic__refresh.html#ga10d1500b07ed1047288473605c079a9c", null ],
    [ "av1_cyclic_refresh_set_golden_update", "group__cyclic__refresh.html#gab14ed0139e8ebd0177d8a4b9c1e273ce", null ],
    [ "av1_cyclic_refresh_update_parameters", "group__cyclic__refresh.html#ga320b85772ac318291cc2bb14c249a1d8", null ],
    [ "av1_cyclic_refresh_setup", "group__cyclic__refresh.html#gafc1304a44c092d497a6cbbbaef92d1b9", null ]
];

==> aom-docs-3.1.1-1-aarch64.pkg.tar.xz: usr/share/doc/aom/group__cyclic__refresh.js <==
var group__cyclic__refresh =
[
    [ "CYCLIC_REFRESH", "structCYCLIC__REFRESH.html", [
      [ "percent_refresh", "structCYCLIC__REFRESH.html#ae315bcaf369b95ab1162f2d1271263de", null ],
      [ "max_qdelta_perc", "structCYCLIC__REFRESH.html#a441d4805353c603874ae7f356a649cd3", null ],
      [ "sb_index", "structCYCLIC__REFRESH.html#ad45cfe66fc5d1ab8aecee9bc1ef72f44", null ],
      [ "time_for_refresh", "structCYCLIC__REFRESH.html#a14a2e1c9b9ca6a36bb29ccd9a0e02002", null ],
      [ "target_num_seg_blocks", "structCYCLIC__REFRESH.html#ac79bf4f50ebef3b6e6fd91e25af9a2c6", null ],
      [ "actual_num_seg1_blocks", "structCYCLIC__REFRESH.html#aebf6363e9a037324981bd3739cdce960", null ],
      [ "actual_num_seg2_blocks", "structCYCLIC__REFRESH.html#a7b30c416581337161479c00e08fed8ea", null ],
      [ "rdmult", "structCYCLIC__REFRESH.html#a383b90c4a87340a91580aac8a537aee6", null ],
      [ "cnt_zeromv", "structCYCLIC__REFRESH.html#a68abf0fd3f8b6d9c3bd9725e71f19fe1", null ],
      [ "map", "structCYCLIC__REFRESH.html#a5034d2e9cba349dd451d41f6362dc6f9", null ],
      [ "last_coded_q_map", "structCYCLIC__REFRESH.html#ad7b64393744b5619addd0780cfaed625", null ],
      [ "thresh_rate_sb", "structCYCLIC__REFRESH.html#a11f1a950d76b9908606d234eab0d8b2b", null ],
      [ "thresh_dist_sb", "structCYCLIC__REFRESH.html#a74276b39125b068743f0b6dc2ba0f36a", null ],
      [ "motion_thresh", "structCYCLIC__REFRESH.html#a08162f2bd6028160d470024577dfcec6", null ],
      [ "rate_ratio_qdelta", "structCYCLIC__REFRESH.html#afe7bf45e2c31665d7d64254c23fdaf6c", null ],
      [ "rate_boost_fac", "structCYCLIC__REFRESH.html#ae0966dda4b2470d422129ed473e39d4c", null ]
    ] ],
    [ "av1_cyclic_refresh_estimate_bits_at_q", "group__cyclic__refresh.html#ga3703e9a518f8f17e7b6b601a456dbde8", null ],
    [ "av1_cyclic_refresh_rc_bits_per_mb", "group__cyclic__refresh.html#ga1e8e194fae8285692651fb856b49c185", null ],
    [ "av1_cyclic_refresh_update_segment", "group__cyclic__refresh.html#ga35ec71ccbbc64bcb31ed02229dfe9ae0", null ],
    [ "av1_init_cyclic_refresh_counters", "group__cyclic__refresh.html#gab63536700b85e6560aed37f0b8afbcaf", null ],
    [ "av1_accumulate_cyclic_refresh_counters", "group__cyclic__refresh.html#gaa4acc60c7ec3fc459b5ce65920493823", null ],
    [ "av1_cyclic_refresh_postencode", "group__cyclic__refresh.html#ga10d1500b07ed1047288473605c079a9c", null ],
    [ "av1_cyclic_refresh_set_golden_update", "group__cyclic__refresh.html#gab14ed0139e8ebd0177d8a4b9c1e273ce", null ],
    [ "av1_cyclic_refresh_update_parameters", "group__cyclic__refresh.html#ga320b85772ac318291cc2bb14c249a1d8", null ],
    [ "av1_cyclic_refresh_setup", "group__cyclic__refresh.html#gafc1304a44c092d497a6cbbbaef92d1b9", null ]
];
